@@ -19,7 +19,9 @@
 #include <common/checksums.h>
 #include "wordlist.h"
 
-#include <qt5keychain/keychain.h>
+#include <qt6keychain/keychain.h>
+
+#include <KCompressionDevice>
 
 #include <QDebug>
 #include <QLoggingCategory>
@@ -37,8 +39,6 @@
 #include <QJsonArray>
 #include <QCryptographicHash>
 
-#include <KCompressionDevice>
-
 #include <map>
 #include <string>
 #include <algorithm>
@@ -224,31 +224,52 @@ QByteArray generateRandom(int size)
     return result;
 }
 
-QByteArray generatePassword(const QString& wordlist, const QByteArray& salt) {
-    qCInfo(lcCse()) << "Start encryption key generation!";
-
-    const int iterationCount = 1024;
-    const int keyStrength = 256;
-    const int keyLength = keyStrength/8;
+QByteArray deprecatedGeneratePassword(const QString& wordlist, const QByteArray& salt)
+{
+    const auto iterationCount = 1024;
+    const auto keyStrength = 256;
+    const auto keyLength = keyStrength / 8;
 
     QByteArray secretKey(keyLength, '\0');
 
-    int ret = PKCS5_PBKDF2_HMAC_SHA1(
-        wordlist.toLocal8Bit().constData(),     // const char *password,
-        wordlist.size(),                        // int password length,
-        (const unsigned char *)salt.constData(),// const unsigned char *salt,
-        salt.size(),                            // int saltlen,
-        iterationCount,                         // int iterations,
-        keyLength,                              // int keylen,
-        unsignedData(secretKey)                 // unsigned char *out
-        );
+    const auto ret = PKCS5_PBKDF2_HMAC(wordlist.toLocal8Bit().constData(),     // const char *password,
+                                       wordlist.size(),                        // int password length,
+                                       (const unsigned char *)salt.constData(),// const unsigned char *salt,
+                                       salt.size(),                            // int saltlen,
+                                       iterationCount,                         // int iterations,
+                                       EVP_sha1(),                             // digest algorithm
+                                       keyLength,                              // int keylen,
+                                       unsignedData(secretKey));               // unsigned char *out
 
     if (ret != 1) {
-        qCInfo(lcCse()) << "Failed to generate encryption key";
+        qCWarning(lcCse()) << "Failed to generate encryption key";
         // Error out?
     }
 
-    qCInfo(lcCse()) << "Encryption key generated!";
+    return secretKey;
+}
+
+QByteArray generatePassword(const QString& wordlist, const QByteArray& salt)
+{
+    const auto iterationCount = 600000;
+    const auto keyStrength = 256;
+    const auto keyLength = keyStrength / 8;
+
+    QByteArray secretKey(keyLength, '\0');
+
+    const auto ret = PKCS5_PBKDF2_HMAC(wordlist.toLocal8Bit().constData(),     // const char *password,
+                                       wordlist.size(),                        // int password length,
+                                       (const unsigned char *)salt.constData(),// const unsigned char *salt,
+                                       salt.size(),                            // int saltlen,
+                                       iterationCount,                         // int iterations,
+                                       EVP_sha1(),                             // digest algorithm
+                                       keyLength,                              // int keylen,
+                                       unsignedData(secretKey));               // unsigned char *out
+
+    if (ret != 1) {
+        qCWarning(lcCse()) << "Failed to generate encryption key";
+        // Error out?
+    }
 
     return secretKey;
 }
@@ -1195,7 +1216,7 @@ void ClientSideEncryption::getUsersPublicKeyFromServer(const AccountPtr &account
     const auto job = new JsonApiJob(account, e2eeBaseUrl(account) + QStringLiteral("public-key"), this);
     connect(job, &JsonApiJob::jsonReceived, [this, account, userIds](const QJsonDocument &doc, int retCode) {
         if (retCode == 200) {
-            QHash<QString, QSslCertificate> results;
+            QHash<QString, NextcloudSslCertificate> results;
             const auto publicKeys = doc.object()[QStringLiteral("ocs")].toObject()[QStringLiteral("data")].toObject()[QStringLiteral("public-keys")].toObject();
             for (const auto &userId : publicKeys.keys()) {
                 if (userIds.contains(userId)) {
@@ -1639,11 +1660,15 @@ void ClientSideEncryption::decryptPrivateKey(const AccountPtr &account, const QB
             // split off salt
             const auto salt = EncryptionHelper::extractPrivateKeySalt(key);
 
-            auto pass = EncryptionHelper::generatePassword(mnemonic, salt);
+            const auto deprecatedPassword = EncryptionHelper::deprecatedGeneratePassword(mnemonic, salt);
+            const auto password = EncryptionHelper::generatePassword(mnemonic, salt);
 
-            QByteArray privateKey = EncryptionHelper::decryptPrivateKey(pass, key);
-            //_privateKey = QSslKey(privateKey, QSsl::Rsa, QSsl::Pem, QSsl::PrivateKey);
-            _privateKey = privateKey;
+            const auto privateKey = EncryptionHelper::decryptPrivateKey(password, key);
+            if (!privateKey.isEmpty()) {
+                _privateKey = privateKey;
+            } else {
+                _privateKey = EncryptionHelper::decryptPrivateKey(deprecatedPassword, key);
+            }
 
             if (!_privateKey.isNull() && checkPublicKeyValidity(account)) {
                 writePrivateKey(account);
@@ -2302,4 +2327,57 @@ bool EncryptionHelper::StreamingDecryptor::isFinished() const
 {
     return _isFinished;
 }
+
+NextcloudSslCertificate::NextcloudSslCertificate() = default;
+
+NextcloudSslCertificate::NextcloudSslCertificate(const NextcloudSslCertificate &other) = default;
+
+NextcloudSslCertificate::NextcloudSslCertificate(const QSslCertificate &certificate)
+    : _certificate(certificate)
+{
+}
+
+NextcloudSslCertificate::NextcloudSslCertificate(QSslCertificate &&certificate)
+    : _certificate(std::move(certificate))
+{
+}
+
+OCC::NextcloudSslCertificate::operator QSslCertificate()
+{
+    return _certificate;
+}
+
+QSslCertificate &NextcloudSslCertificate::get()
+{
+    return _certificate;
+}
+
+const QSslCertificate &NextcloudSslCertificate::get() const
+{
+    return _certificate;
+}
+
+NextcloudSslCertificate &NextcloudSslCertificate::operator=(const NextcloudSslCertificate &other)
+{
+    if (this != &other) {
+        _certificate = other._certificate;
+    }
+
+    return *this;
+}
+
+NextcloudSslCertificate &NextcloudSslCertificate::operator=(NextcloudSslCertificate &&other)
+{
+    if (this != &other) {
+        _certificate = std::move(other._certificate);
+    }
+
+    return *this;
+}
+
+OCC::NextcloudSslCertificate::operator QSslCertificate() const
+{
+    return _certificate;
+}
+
 }
