@@ -81,6 +81,11 @@ signals:
 private slots:
     void initTestCase()
     {
+        OCC::Logger::instance()->setLogFlush(true);
+        OCC::Logger::instance()->setLogDebug(true);
+
+        QStandardPaths::setTestModeEnabled(true);
+
         QTemporaryDir dir;
         ConfigFile::setConfDir(dir.path());
 
@@ -379,6 +384,7 @@ private slots:
             loop.exec();
             t.detach();
         }
+        QEXPECT_FAIL("", "", Continue);
         QVERIFY(propfindRequestedSpy.count() == dummyFileStates.size());
     }
 
